/// @file        TchContr_Fusion.h
/// @copyright     Copyright (c) 2012 Toradex AG \n
///             All information contained herein is, and remains the property of Toradex Ag and its suppliers, if any. The intellectual\n
///             and technical concepts contained herein are proprietary to Toradex AG and its suppliers and may be covered by Swiss and\n
///             foreign patents, patents in process, and are protected by trade secret or copyright law. Dissemination of this information\n
///             or reproduction of this material is strictly forbidden unless prior written permission is obtained from Toradex AG.\n
/// @author      $Author$
/// @version     $Rev$
/// @date        $Date$
/// @brief       Fuction library for the touch controller Fusion
///                GeneralError concept:
///                Every functon, witch can dedect errors, has as a return value BOOL ->  TRUE = ok, FALSE = error
///                The Details of the error itself is loged to the debug port.
/// @target        Colibri PXA270, PX3xx, T20 WinCE5, WinCE6, WinEC7
/// @caveats

#ifndef __TCHCONTRFUSION_H__
#define __TCHCONTRFUSION_H__

#include "unfd_multitchdrv.h"

// #define TRACE_ON    1
// #define TRIGGER_ON 1

//==== public methods declarations ===============================================================

/// Set the configuration data according to the registry entry or to the default value.
/// These data are "INT port number", "RESET port number", "I2C slave address", "I2C speed",
/// @param[in]    none
/// @param[out]   none
/// @retval       none
/// @caveats      none
void vI2C_ReadConfiguration(void);

/// Init the I2C communcation incl.the GIPO for the "INT" and "RST" pin of the touch controller
/// @param[in]    none
/// @param[out]   none
/// @retval       TRUE  success
/// @retval       FALSE error, a message to the debug console shows the reason
/// @caveats      vI2C_ReadConfiguration() has to be executed
BOOL bI2C_Init(void);

/// Stop the I2C communication (release interrrupt, mutex, stop the I2C driver etc)
/// @param[in]    none
/// @param[out]   none
/// @retval       none
/// @retval       none
/// @caveats      none
void vI2C_DeInit(void);

/// Start the touch controller (release the RST/PWR line) start the commincation and and setup the\n
/// nessesary registers in the touch controller
/// @param[in]    none
/// @param[out]   none
/// @retval       TRUE  success
/// @retval       FALSE error, a message to the debug console shows the reason
/// @caveats      none
BOOL bInitFusion(void);

/// Release the current interrupt and wait for the next interrupt with timeout
/// @param[in]    none
/// @param[out]   none
/// @retval       TRUE  Interrupt
/// @retval       FALSE Timeout
/// @caveats      none
BOOL bWaitTouchDataINT(void);

/// Test the communication by reading out the vedors's chp id
/// @param[in]    none
/// @param[out]   none
/// @retval       TRUE  success
/// @retval       FALSE communcation error wit the touch controller,
/// @caveats      none
BOOL bCommunicationTestFusion(void);


/// Get the touch events from the controller
/// @param[in]    pInput = pointer to an array[2] of TCHINPUT, pCnt = pointer to count of touches
/// @param[out]   pInput = pointer to an array[2] of TCHINPUT, pCnt = pointer to count of touches
/// @retval       TRUE  success
/// @retval       FALSE communcation error wit the touch controller,
/// @caveats      none
void vTouchPanelGetPoint(PTCHINPUT pInput,INT *pCnt);


/// Reset on or power off the touch controller\n
/// Because the touch controller is mounted very closed to the diaplay an ESD pulse could disturb the controler in a way that his is not working anymore (not broken for ever)
/// @param[in]    none
/// @param[out]   none
/// @retval       none
/// @caveats      none
void vDeInitFusion(void);

#ifdef TRACE_ON

// reset index and whole touch buffer
void TraceTchClear(void);

// write touch data to the controller buffer
void TraceTchPut(CETCHINP_IOCTL *pTchBuf);

// print out the whole touch data buffer
void TraceTchPrint(void);

#endif

#ifdef TRIGGER_ON
/// Set the trigger output to high

/// Set the trigger output to high
/// @param[in]    none
/// @param[out]   none
/// @retval       none
/// @caveats      none
void vSetTriggerHigh(void);

/// Set the trigger output to low
/// @param[in]    none
/// @param[out]   none
/// @retval       none
/// @caveats      none
void vSetTriggerLow(void);

#endif


#endif //  __TCHCONTRFUSION_H__

